extract_fires: extract_fires

View source: R/prepare.R

extract_firesR Documentation

extract_fires

Description

Pull fire information from GOES-R ABI netcdf files and return a csv with lat/lon info

Usage

extract_fires(filename, vars = c("Temp", "Power", "Area", "DQF", "Mask"),
  maskvals = NULL)

Arguments

filename

the full path name of the netcdf FDC file to process

vars

The variables to include in the output among c("Temp", "Power", "Area", "DQF", "Mask"). All are included by default.

maskvals

If "Mask" is selected in vars, these are the mask values to keep. If no mask values are selected, all pixels will be returned and the output will be very large.

Value

A data frame with latitude, longitude, time, and the variables requested.

Examples

df <- extract_fires(infile, maskvals = c(10, 11, 30, 31))

raffscallion/goesfire documentation built on June 9, 2025, 2:46 a.m.