process_fire_cubes: process_fire_cubes

View source: R/cube.R

process_fire_cubesR Documentation

process_fire_cubes

Description

Takes a set of fire bounding boxes, expressed as a data frame with start and end dates and lat/lon bounds and runs create cube on each, storing the results as RDS files - one per data frame row

Usage

process_fire_cubes(df, input_path, output_path, variables = c("Mask",
  "Area", "Power"), coords = NULL)

Arguments

df

A data frame with the following fields: fire_name and sf_id (will be the name of the output RDS file); sf_start and sf_end (begin and end dates of fire); xmin, ymin, xmax, and ymax (coordinates of the fire's bounding box)

...

Additional parameters passed to create_cube

Value

Returns the list of fire names processed


raffscallion/goesfire documentation built on June 9, 2025, 2:46 a.m.