| download_and_process | R Documentation |
Given a filename, URL of a file available via ftp, and download path, it will download and process the file if it does not already exist in the download path.
download_and_process(filename, url, download_path, vars = c("Temp",
"Power", "Area", "DQF", "Mask"), maskvals = c(10, 11, 30, 31),
calc_emissions = FALSE, feer = NULL)
filename |
A netcdf filename |
url |
The ftp location of the file, including subdirectories |
download_path |
The local download location |
vars |
The variables to process (passed to |
maskvals |
If the "Mask" variable is included in vars, this is the list of mask
values to include in the output. The default is c(10, 11, 30, 31). If not included,
all pixels will be processed and the output will be very large. Passed to
|
calc_emissions |
logical Calculate emissions (FRE and TPM) using FEER |
feer |
The FEERv1.0_Ce.csv file loaded as a data frame. This can be acquired from https://feer.gsfc.nasa.gov/ |
A data frame of processed fire data, and the original file downloaded in download_path
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.