| extract_fires | R Documentation |
Pull fire information from GOES-R ABI netcdf files and return a csv with lat/lon info
extract_fires(filename, vars = c("Temp", "Power", "Area", "DQF", "Mask"),
maskvals = NULL)
filename |
the full path name of the netcdf FDC file to process |
vars |
The variables to include in the output among c("Temp", "Power", "Area", "DQF", "Mask"). All are included by default. |
maskvals |
If "Mask" is selected in vars, these are the mask values to keep. If no mask values are selected, all pixels will be returned and the output will be very large. |
A data frame with latitude, longitude, time, and the variables requested.
df <- extract_fires(infile, maskvals = c(10, 11, 30, 31))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.